@@ -51,10 +51,10 @@ class KSImageWidget : public QLabel
 
     protected:
 
-    void mousePressEvent(QMouseEvent *event)   Q_DECL_OVERRIDE;
-    void mouseReleaseEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
-    void mouseMoveEvent(QMouseEvent *event)    Q_DECL_OVERRIDE;
-    void resizeEvent(QResizeEvent *event)      Q_DECL_OVERRIDE;
+    void mousePressEvent(QMouseEvent *event)   override;
+    void mouseReleaseEvent(QMouseEvent *event) override;
+    void mouseMoveEvent(QMouseEvent *event)    override;
+    void resizeEvent(QResizeEvent *event)      override;
 
     private:
 
