@@ -49,22 +49,22 @@ static const int DEFAULT_WINDOW_HEIGHT = 420;
 static const int DEFAULT_WINDOW_WIDTH = 840;
 static const int MAXIMUM_WINDOW_WIDTH = 1000;
 
-KSMainWindow::KSMainWindow(bool onClickAvailable, QWidget *parent) :
+KSMainWindow::KSMainWindow(const QVector<ImageGrabber::GrabMode>& supportedModes, bool onClickAvailable, QWidget *parent) :
     QDialog(parent),
-    mKSWidget(new KSWidget),
-    mDivider(new QFrame),
-    mDialogButtonBox(new QDialogButtonBox),
-    mConfigureButton(new QToolButton),
-    mToolsButton(new QPushButton),
-    mSendToButton(new QPushButton),
-    mClipboardButton(new QToolButton),
-    mSaveButton(new QToolButton),
-    mSaveMenu(new QMenu),
+    mKSWidget(new KSWidget(supportedModes, this)),
+    mDivider(new QFrame(this)),
+    mDialogButtonBox(new QDialogButtonBox(this)),
+    mConfigureButton(new QToolButton(this)),
+    mToolsButton(new QPushButton(this)),
+    mSendToButton(new QPushButton(this)),
+    mClipboardButton(new QToolButton(this)),
+    mSaveButton(new QToolButton(this)),
+    mSaveMenu(new QMenu(this)),
     mSaveAsAction(new QAction(this)),
     mSaveAction(new QAction(this)),
-    mMessageWidget(new KMessageWidget),
-    mToolsMenu(new QMenu),
-    mScreenRecorderToolsMenu(new QMenu),
+    mMessageWidget(new KMessageWidget(this)),
+    mToolsMenu(new QMenu(this)),
+    mScreenRecorderToolsMenu(new QMenu(this)),
     mExportMenu(new ExportMenu(this)),
     mOnClickAvailable(onClickAvailable)
 {
@@ -99,9 +99,9 @@ KSMainWindow::KSMainWindow(bool onClickAvailable, QWidget *parent) :
         uint32_t value = 1;
         xcb_change_property(xcbConn, XCB_PROP_MODE_REPLACE, winId(), atom->atom, XCB_ATOM_CARDINAL, 32, 1, &value);
     }
+    done:
 #endif
 
-    done:
     QMetaObject::invokeMethod(this, "init", Qt::QueuedConnection);
 }
 
@@ -141,7 +141,8 @@ void KSMainWindow::init()
     mDialogButtonBox->addButton(mConfigureButton, QDialogButtonBox::ResetRole);
 
     KGuiItem::assign(mToolsButton, KGuiItem(i18n("Tools")));
-    mToolsButton->setIcon(QIcon::fromTheme(QStringLiteral("application-menu")));
+    mToolsButton->setIcon(QIcon::fromTheme(QStringLiteral("tools"),
+                                           QIcon::fromTheme(QStringLiteral("application-menu"))));
     mDialogButtonBox->addButton(mToolsButton, QDialogButtonBox::ActionRole);
     mToolsButton->setMenu(mToolsMenu);
 
@@ -172,7 +173,9 @@ void KSMainWindow::init()
     mScreenRecorderToolsMenu = mToolsMenu->addMenu(i18n("Record Screen"));
     connect(mScreenRecorderToolsMenu, &QMenu::aboutToShow, [this]()
     {
-        mScreenrecorderToolsMenuFactory.reset(new KMoreToolsMenuFactory(QStringLiteral("spectacle/screenrecorder-tools")));
+        KMoreToolsMenuFactory *moreToolsMenuFactory = new KMoreToolsMenuFactory(QStringLiteral("spectacle/screenrecorder-tools"));
+        moreToolsMenuFactory->setParentWidget(this);
+        mScreenrecorderToolsMenuFactory.reset(moreToolsMenuFactory);
         mScreenRecorderToolsMenu->clear();
         mScreenrecorderToolsMenuFactory->fillMenuFromGroupingNames(mScreenRecorderToolsMenu, { QStringLiteral("screenrecorder") });
     } );
@@ -297,15 +300,15 @@ void KSMainWindow::showPrintDialog()
 
 void KSMainWindow::openScreenshotsFolder()
 {
-    // Highlight last screenshot in file manager if user saved at least once ever 
-    // (since last save and saveas file names are stored in spectaclerc), otherwise, 
+    // Highlight last screenshot in file manager if user saved at least once ever
+    // (since last save and saveas file names are stored in spectaclerc), otherwise,
     //   if in save mode, open default save location from configure > save > location
     //   if in save as mode, open last save as files location
     // failsafe for either option is default save location from configure > save > location
     SpectacleConfig *cfgManager = SpectacleConfig::instance();
     ExportManager *exportManager = ExportManager::instance();
     QUrl location;
-    
+
     switch(cfgManager->lastUsedSaveMode()) {
     case SaveMode::Save:
         location = cfgManager->lastSaveFile();
@@ -400,7 +403,7 @@ void KSMainWindow::showPreferencesDialog()
     prefDialog.exec();
 }
 
-void KSMainWindow::setScreenshotWindowTitle(QUrl location)
+void KSMainWindow::setScreenshotWindowTitle(const QUrl &location)
 {
     setWindowTitle(location.fileName());
     setWindowModified(false);
