@@ -32,19 +32,20 @@ class DummyImageGrabber : public ImageGrabber
     public:
 
     explicit DummyImageGrabber(QObject *parent = nullptr);
-    ~DummyImageGrabber() Q_DECL_OVERRIDE;
+    ~DummyImageGrabber() override;
 
-    bool onClickGrabSupported() const Q_DECL_OVERRIDE;
+    QVector<ImageGrabber::GrabMode> supportedModes() const override { return {FullScreen, CurrentScreen, ActiveWindow, WindowUnderCursor, TransientWithParent, RectangularRegion}; }
+    bool onClickGrabSupported() const override;
 
     protected:
 
-    QPixmap blendCursorImage(const QPixmap &pixmap, int x, int y, int width, int height) Q_DECL_OVERRIDE;
-    void grabFullScreen()          Q_DECL_OVERRIDE;
-    void grabCurrentScreen()       Q_DECL_OVERRIDE;
-    void grabActiveWindow()        Q_DECL_OVERRIDE;
-    void grabRectangularRegion()   Q_DECL_OVERRIDE;
-    void grabWindowUnderCursor()   Q_DECL_OVERRIDE;
-    void grabTransientWithParent() Q_DECL_OVERRIDE;
+    QPixmap blendCursorImage(const QPixmap &pixmap, int x, int y, int width, int height) override;
+    void grabFullScreen()          override;
+    void grabCurrentScreen()       override;
+    void grabActiveWindow()        override;
+    void grabRectangularRegion()   override;
+    void grabWindowUnderCursor()   override;
+    void grabTransientWithParent() override;
 };
 
 #endif // DUMMYIMAGEGRABBER_H
